<?php

use Nette\Forms\Form;
use Instante\Bootstrap3Renderer\BootstrapRenderer;

$app->get('/', function () use ($app) {
    $app->redirect(ROOT_URL . '/matches');
});

function login_form() {
    $form = new Form;
    $form->setRenderer(new BootstrapRenderer);
    $form->setAction('login');

    $form->addText('username', _('Username'))
        ->setRequired();
    $form->addPassword('password', _('Password'))
        ->setRequired();
    $form->addCheckbox('remember', _('Remember me'));
    $form->addSubmit('send', _('Login'));

    return $form;
}

$app->get('/login', function () use ($app, $user) {
    $user->isLoggedIn() && $app->redirect(ROOT_URL);
    $app->render('login', array('form' => login_form()));
});

$app->post('/login', function () use ($config, $app, $user, $session) {
    $form = login_form();
    $form->validate();

    if (!$form->hasErrors()) {
        $values = $form->getValues();

        try {
            $user->login($values->username, $values->password);

            if ($values->remember)
                $user->setExpiration($config['max_session_lifetime'], false);
            else
                $user->setExpiration(0, true);

            $app->redirect(ROOT_URL);
        } catch (Nette\Security\AuthenticationException $e) {
            $form->addError($e->getMessage());
        }
    }

    $app->render('login', compact('form'));
});

$app->get('/logout', function () use ($app, $user) {
    $user->logout();
    $app->redirect(ROOT_URL);
});
